readfish plugins API
====================

``readfish.plugins.abc`` module
-------------------------------

.. automodule:: readfish.plugins.abc
   :members:
   :undoc-members:
   :show-inheritance:

----

``readfish.plugins.utils`` module
---------------------------------

.. automodule:: readfish.plugins.utils
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

----

``readfish.plugins.guppy`` module
---------------------------------

.. automodule:: readfish.plugins.guppy
   :members:
   :undoc-members:
   :show-inheritance:

----

``readfish.plugins.mappy`` module
---------------------------------

.. automodule:: readfish.plugins.mappy
   :members:
   :undoc-members:
   :show-inheritance:

``readfish.plugins._no_op`` module
----------------------------------

.. automodule:: readfish.plugins._no_op
   :members:
   :undoc-members:
   :show-inheritance:
